==> ecs-crd-cli-0.10.0.tar.gz: ecs-crd-cli-0.10.0/ecs_crd/sendNotificationBySnsStep.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import boto3

from ecs_crd.finishDeploymentStep import FinishDeploymentStep
from ecs_crd.canaryReleaseDeployStep import CanaryReleaseDeployStep

class SendNotificationBySnsStep(CanaryReleaseDeployStep):
    
    def __init__(self, infos, logger):
        """initializes a new instance of the class"""
        super().__init__(infos, 'Send Nofification', logger, with_end_log=False)

    def _find_sns_topic_notifcation(self):
        if 'sns_topic_notifications' in self.configuration['canary']:
            result = self.configuration['canary']['sns_topic_notifications']
            if self.infos.exit_code == 0 and 'on_success' in  result:
                return self.bind_data(result['on_success'])
            if self.infos.exit_code != 0 and 'on_fail' in  result:
                return self.bind_data(result['on_fail'])
            return None

    def _on_execute(self):
        sns_topic_notification = self._find_sns_topic_notifcation()
        
        if sns_topic_notification:
            message = f'ECS canary {self.infos.action } of the "{self.infos.service_name}" service was successful.'
            if self.infos.exit_code != 0:
                message = f'ECS canary {self.infos.action } of the "{self.infos.service_name}" service was failed.'
            message +=f'\nAccount        : {self.infos.account_id}'
            message +=f'\nRegion         : {self.infos.region}'
            message +=f'\nEnvironment    : {self.infos.environment}'
            message +=f'\nCluster        : {self.infos.cluster_name}'
            message +=f'\nProject        : {self.infos.project}'
            message +=f'\nService        : {self.infos.service_name}'
            message +=f'\nVersion        : {self.infos.service_version}'
            message +=f'\nFqdn           : {self.infos.fqdn}'
            message +=f'\nExit Code      : {self.infos.exit_code}'
            message +=f'\nMessage        : {self.infos.exit_exception}'
            subject = ('[SUCCESS]' if self.infos.exit_code == 0 else ['FAIL']) + f' {self.infos.action} - {self.infos.service_name}' 
            client = boto3.client('sns', region_name=self.infos.region)
            self._log_information(key='Sending Notification ... ', value=None)
            try:
                response = client.publish(
                    TopicArn = sns_topic_notification,
                    Message = message,
                    Subject = subject
                )
                self._log_information(key='Notififcation sended with success', value=None)
            except Exception as e:
                if self.infos.exit_code == 0:
                    self.infos.exit_code = 100
                    self.infos.exit_exception = e
                self.logger.error(self.title, exc_info=True)
        return FinishDeploymentStep(self.infos, self.logger)

==> ecs-crd-cli-0.11.0.tar.gz: ecs-crd-cli-0.11.0/ecs_crd/sendNotificationBySnsStep.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import boto3

from ecs_crd.finishDeploymentStep import FinishDeploymentStep
from ecs_crd.canaryReleaseDeployStep import CanaryReleaseDeployStep

class SendNotificationBySnsStep(CanaryReleaseDeployStep):
    
    def __init__(self, infos, logger):
        """initializes a new instance of the class"""
        super().__init__(infos, 'Send Notification', logger, with_end_log=False)

    def _find_sns_topic_notifcation(self):
        if 'sns_topic_notifications' in self.configuration['canary']:
            result = self.configuration['canary']['sns_topic_notifications']
            if self.infos.exit_code == 0 and 'on_success' in  result:
                return self.bind_data(result['on_success'])
            if self.infos.exit_code != 0 and 'on_fail' in  result:
                return self.bind_data(result['on_fail'])
            return None

    def _on_execute(self):
        sns_topic_notification = self._find_sns_topic_notifcation()
        if sns_topic_notification:
            message = f'ECS canary {self.infos.action} of the "{self.infos.service_name}" service was successful.'
            if self.infos.exit_code != 0:
                message = f'ECS canary {self.infos.action} of the "{self.infos.service_name}" service was failed.'
            message +=f'\nAccount        : {self.infos.account_id}'
            message +=f'\nRegion         : {self.infos.region}'
            message +=f'\nEnvironment    : {self.infos.environment}'
            message +=f'\nCluster        : {self.infos.cluster_name}'
            message +=f'\nProject        : {self.infos.project}'
            message +=f'\nService        : {self.infos.service_name}'
            message +=f'\nVersion        : {self.infos.service_version}'
            message +=f'\nFqdn           : {self.infos.fqdn}'
            message +=f'\nExit Code      : {self.infos.exit_code}'
            message +=f'\nMessage        : {self.infos.exit_exception}'
            subject = '[SUCCESS]' if self.infos.exit_code == 0 else '[FAIL]'
            subject += f' {self.infos.action} - {self.infos.service_name}' 
            client = boto3.client('sns', region_name=self.infos.region)
            self._log_information(key='Sending Notification ... ', value=None)
            try:
                client.publish(
                    TopicArn = sns_topic_notification,
                    Message = message,
                    Subject = subject
                )
                self._log_information(key='Notification sended with success.', value=None)
            except Exception as e:
                if self.infos.exit_code == 0:
                    self.infos.exit_code = 100
                    self.infos.exit_exception = e
                self.logger.error(self.title, exc_info=True)
        return FinishDeploymentStep(self.infos, self.logger)
